# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: v5.8.3.8933
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class QualitySource(str, Enum):
    """
    QualitySource
    """

    """
    allowed enum values
    """
    UNKNOWN = 'unknown'
    CAM = 'cam'
    TELESYNC = 'telesync'
    TELECINE = 'telecine'
    WORKPRINT = 'workprint'
    DVD = 'dvd'
    TV = 'tv'
    WEBDL = 'webdl'
    WEBRIP = 'webrip'
    BLURAY = 'bluray'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of QualitySource from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: v5.8.3.8933
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from radarr.models.download_protocol import DownloadProtocol
from typing import Optional, Set
from typing_extensions import Self

class DelayProfileResource(BaseModel):
    """
    DelayProfileResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    enable_usenet: Optional[StrictBool] = Field(default=None, alias="enableUsenet")
    enable_torrent: Optional[StrictBool] = Field(default=None, alias="enableTorrent")
    preferred_protocol: Optional[DownloadProtocol] = Field(default=None, alias="preferredProtocol")
    usenet_delay: Optional[StrictInt] = Field(default=None, alias="usenetDelay")
    torrent_delay: Optional[StrictInt] = Field(default=None, alias="torrentDelay")
    bypass_if_highest_quality: Optional[StrictBool] = Field(default=None, alias="bypassIfHighestQuality")
    bypass_if_above_custom_format_score: Optional[StrictBool] = Field(default=None, alias="bypassIfAboveCustomFormatScore")
    minimum_custom_format_score: Optional[StrictInt] = Field(default=None, alias="minimumCustomFormatScore")
    order: Optional[StrictInt] = None
    tags: Optional[List[StrictInt]] = None
    __properties: ClassVar[List[str]] = ["id", "enableUsenet", "enableTorrent", "preferredProtocol", "usenetDelay", "torrentDelay", "bypassIfHighestQuality", "bypassIfAboveCustomFormatScore", "minimumCustomFormatScore", "order", "tags"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DelayProfileResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DelayProfileResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "enableUsenet": obj.get("enableUsenet"),
            "enableTorrent": obj.get("enableTorrent"),
            "preferredProtocol": obj.get("preferredProtocol"),
            "usenetDelay": obj.get("usenetDelay"),
            "torrentDelay": obj.get("torrentDelay"),
            "bypassIfHighestQuality": obj.get("bypassIfHighestQuality"),
            "bypassIfAboveCustomFormatScore": obj.get("bypassIfAboveCustomFormatScore"),
            "minimumCustomFormatScore": obj.get("minimumCustomFormatScore"),
            "order": obj.get("order"),
            "tags": obj.get("tags")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: v5.8.3.8933
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from radarr.models.language import Language
from radarr.models.profile_format_item_resource import ProfileFormatItemResource
from radarr.models.quality_profile_quality_item_resource import QualityProfileQualityItemResource
from typing import Optional, Set
from typing_extensions import Self

class QualityProfileResource(BaseModel):
    """
    QualityProfileResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    upgrade_allowed: Optional[StrictBool] = Field(default=None, alias="upgradeAllowed")
    cutoff: Optional[StrictInt] = None
    items: Optional[List[QualityProfileQualityItemResource]] = None
    min_format_score: Optional[StrictInt] = Field(default=None, alias="minFormatScore")
    cutoff_format_score: Optional[StrictInt] = Field(default=None, alias="cutoffFormatScore")
    format_items: Optional[List[ProfileFormatItemResource]] = Field(default=None, alias="formatItems")
    language: Optional[Language] = None
    __properties: ClassVar[List[str]] = ["id", "name", "upgradeAllowed", "cutoff", "items", "minFormatScore", "cutoffFormatScore", "formatItems", "language"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of QualityProfileResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item in self.items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['items'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in format_items (list)
        _items = []
        if self.format_items:
            for _item in self.format_items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formatItems'] = _items
        # override the default output from pydantic by calling `to_dict()` of language
        if self.language:
            _dict['language'] = self.language.to_dict()
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if items (nullable) is None
        # and model_fields_set contains the field
        if self.items is None and "items" in self.model_fields_set:
            _dict['items'] = None

        # set to None if format_items (nullable) is None
        # and model_fields_set contains the field
        if self.format_items is None and "format_items" in self.model_fields_set:
            _dict['formatItems'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of QualityProfileResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "upgradeAllowed": obj.get("upgradeAllowed"),
            "cutoff": obj.get("cutoff"),
            "items": [QualityProfileQualityItemResource.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "minFormatScore": obj.get("minFormatScore"),
            "cutoffFormatScore": obj.get("cutoffFormatScore"),
            "formatItems": [ProfileFormatItemResource.from_dict(_item) for _item in obj["formatItems"]] if obj.get("formatItems") is not None else None,
            "language": Language.from_dict(obj["language"]) if obj.get("language") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: v5.8.3.8933
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from radarr.models.contract_field import ContractField
from radarr.models.provider_message import ProviderMessage
from typing import Optional, Set
from typing_extensions import Self

class NotificationResource(BaseModel):
    """
    NotificationResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    fields: Optional[List[ContractField]] = None
    implementation_name: Optional[StrictStr] = Field(default=None, alias="implementationName")
    implementation: Optional[StrictStr] = None
    config_contract: Optional[StrictStr] = Field(default=None, alias="configContract")
    info_link: Optional[StrictStr] = Field(default=None, alias="infoLink")
    message: Optional[ProviderMessage] = None
    tags: Optional[List[StrictInt]] = None
    presets: Optional[List[NotificationResource]] = None
    link: Optional[StrictStr] = None
    on_grab: Optional[StrictBool] = Field(default=None, alias="onGrab")
    on_download: Optional[StrictBool] = Field(default=None, alias="onDownload")
    on_upgrade: Optional[StrictBool] = Field(default=None, alias="onUpgrade")
    on_rename: Optional[StrictBool] = Field(default=None, alias="onRename")
    on_movie_added: Optional[StrictBool] = Field(default=None, alias="onMovieAdded")
    on_movie_delete: Optional[StrictBool] = Field(default=None, alias="onMovieDelete")
    on_movie_file_delete: Optional[StrictBool] = Field(default=None, alias="onMovieFileDelete")
    on_movie_file_delete_for_upgrade: Optional[StrictBool] = Field(default=None, alias="onMovieFileDeleteForUpgrade")
    on_health_issue: Optional[StrictBool] = Field(default=None, alias="onHealthIssue")
    include_health_warnings: Optional[StrictBool] = Field(default=None, alias="includeHealthWarnings")
    on_health_restored: Optional[StrictBool] = Field(default=None, alias="onHealthRestored")
    on_application_update: Optional[StrictBool] = Field(default=None, alias="onApplicationUpdate")
    on_manual_interaction_required: Optional[StrictBool] = Field(default=None, alias="onManualInteractionRequired")
    supports_on_grab: Optional[StrictBool] = Field(default=None, alias="supportsOnGrab")
    supports_on_download: Optional[StrictBool] = Field(default=None, alias="supportsOnDownload")
    supports_on_upgrade: Optional[StrictBool] = Field(default=None, alias="supportsOnUpgrade")
    supports_on_rename: Optional[StrictBool] = Field(default=None, alias="supportsOnRename")
    supports_on_movie_added: Optional[StrictBool] = Field(default=None, alias="supportsOnMovieAdded")
    supports_on_movie_delete: Optional[StrictBool] = Field(default=None, alias="supportsOnMovieDelete")
    supports_on_movie_file_delete: Optional[StrictBool] = Field(default=None, alias="supportsOnMovieFileDelete")
    supports_on_movie_file_delete_for_upgrade: Optional[StrictBool] = Field(default=None, alias="supportsOnMovieFileDeleteForUpgrade")
    supports_on_health_issue: Optional[StrictBool] = Field(default=None, alias="supportsOnHealthIssue")
    supports_on_health_restored: Optional[StrictBool] = Field(default=None, alias="supportsOnHealthRestored")
    supports_on_application_update: Optional[StrictBool] = Field(default=None, alias="supportsOnApplicationUpdate")
    supports_on_manual_interaction_required: Optional[StrictBool] = Field(default=None, alias="supportsOnManualInteractionRequired")
    test_command: Optional[StrictStr] = Field(default=None, alias="testCommand")
    __properties: ClassVar[List[str]] = ["id", "name", "fields", "implementationName", "implementation", "configContract", "infoLink", "message", "tags", "presets", "link", "onGrab", "onDownload", "onUpgrade", "onRename", "onMovieAdded", "onMovieDelete", "onMovieFileDelete", "onMovieFileDeleteForUpgrade", "onHealthIssue", "includeHealthWarnings", "onHealthRestored", "onApplicationUpdate", "onManualInteractionRequired", "supportsOnGrab", "supportsOnDownload", "supportsOnUpgrade", "supportsOnRename", "supportsOnMovieAdded", "supportsOnMovieDelete", "supportsOnMovieFileDelete", "supportsOnMovieFileDeleteForUpgrade", "supportsOnHealthIssue", "supportsOnHealthRestored", "supportsOnApplicationUpdate", "supportsOnManualInteractionRequired", "testCommand"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NotificationResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in fields (list)
        _items = []
        if self.fields:
            for _item in self.fields:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fields'] = _items
        # override the default output from pydantic by calling `to_dict()` of message
        if self.message:
            _dict['message'] = self.message.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in presets (list)
        _items = []
        if self.presets:
            for _item in self.presets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['presets'] = _items
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if fields (nullable) is None
        # and model_fields_set contains the field
        if self.fields is None and "fields" in self.model_fields_set:
            _dict['fields'] = None

        # set to None if implementation_name (nullable) is None
        # and model_fields_set contains the field
        if self.implementation_name is None and "implementation_name" in self.model_fields_set:
            _dict['implementationName'] = None

        # set to None if implementation (nullable) is None
        # and model_fields_set contains the field
        if self.implementation is None and "implementation" in self.model_fields_set:
            _dict['implementation'] = None

        # set to None if config_contract (nullable) is None
        # and model_fields_set contains the field
        if self.config_contract is None and "config_contract" in self.model_fields_set:
            _dict['configContract'] = None

        # set to None if info_link (nullable) is None
        # and model_fields_set contains the field
        if self.info_link is None and "info_link" in self.model_fields_set:
            _dict['infoLink'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if presets (nullable) is None
        # and model_fields_set contains the field
        if self.presets is None and "presets" in self.model_fields_set:
            _dict['presets'] = None

        # set to None if link (nullable) is None
        # and model_fields_set contains the field
        if self.link is None and "link" in self.model_fields_set:
            _dict['link'] = None

        # set to None if test_command (nullable) is None
        # and model_fields_set contains the field
        if self.test_command is None and "test_command" in self.model_fields_set:
            _dict['testCommand'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NotificationResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "fields": [ContractField.from_dict(_item) for _item in obj["fields"]] if obj.get("fields") is not None else None,
            "implementationName": obj.get("implementationName"),
            "implementation": obj.get("implementation"),
            "configContract": obj.get("configContract"),
            "infoLink": obj.get("infoLink"),
            "message": ProviderMessage.from_dict(obj["message"]) if obj.get("message") is not None else None,
            "tags": obj.get("tags"),
            "presets": [NotificationResource.from_dict(_item) for _item in obj["presets"]] if obj.get("presets") is not None else None,
            "link": obj.get("link"),
            "onGrab": obj.get("onGrab"),
            "onDownload": obj.get("onDownload"),
            "onUpgrade": obj.get("onUpgrade"),
            "onRename": obj.get("onRename"),
            "onMovieAdded": obj.get("onMovieAdded"),
            "onMovieDelete": obj.get("onMovieDelete"),
            "onMovieFileDelete": obj.get("onMovieFileDelete"),
            "onMovieFileDeleteForUpgrade": obj.get("onMovieFileDeleteForUpgrade"),
            "onHealthIssue": obj.get("onHealthIssue"),
            "includeHealthWarnings": obj.get("includeHealthWarnings"),
            "onHealthRestored": obj.get("onHealthRestored"),
            "onApplicationUpdate": obj.get("onApplicationUpdate"),
            "onManualInteractionRequired": obj.get("onManualInteractionRequired"),
            "supportsOnGrab": obj.get("supportsOnGrab"),
            "supportsOnDownload": obj.get("supportsOnDownload"),
            "supportsOnUpgrade": obj.get("supportsOnUpgrade"),
            "supportsOnRename": obj.get("supportsOnRename"),
            "supportsOnMovieAdded": obj.get("supportsOnMovieAdded"),
            "supportsOnMovieDelete": obj.get("supportsOnMovieDelete"),
            "supportsOnMovieFileDelete": obj.get("supportsOnMovieFileDelete"),
            "supportsOnMovieFileDeleteForUpgrade": obj.get("supportsOnMovieFileDeleteForUpgrade"),
            "supportsOnHealthIssue": obj.get("supportsOnHealthIssue"),
            "supportsOnHealthRestored": obj.get("supportsOnHealthRestored"),
            "supportsOnApplicationUpdate": obj.get("supportsOnApplicationUpdate"),
            "supportsOnManualInteractionRequired": obj.get("supportsOnManualInteractionRequired"),
            "testCommand": obj.get("testCommand")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
NotificationResource.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: v5.8.3.8933
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TagDetailsResource(BaseModel):
    """
    TagDetailsResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    label: Optional[StrictStr] = None
    delay_profile_ids: Optional[List[StrictInt]] = Field(default=None, alias="delayProfileIds")
    import_list_ids: Optional[List[StrictInt]] = Field(default=None, alias="importListIds")
    notification_ids: Optional[List[StrictInt]] = Field(default=None, alias="notificationIds")
    release_profile_ids: Optional[List[StrictInt]] = Field(default=None, alias="releaseProfileIds")
    indexer_ids: Optional[List[StrictInt]] = Field(default=None, alias="indexerIds")
    download_client_ids: Optional[List[StrictInt]] = Field(default=None, alias="downloadClientIds")
    auto_tag_ids: Optional[List[StrictInt]] = Field(default=None, alias="autoTagIds")
    movie_ids: Optional[List[StrictInt]] = Field(default=None, alias="movieIds")
    __properties: ClassVar[List[str]] = ["id", "label", "delayProfileIds", "importListIds", "notificationIds", "releaseProfileIds", "indexerIds", "downloadClientIds", "autoTagIds", "movieIds"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TagDetailsResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if label (nullable) is None
        # and model_fields_set contains the field
        if self.label is None and "label" in self.model_fields_set:
            _dict['label'] = None

        # set to None if delay_profile_ids (nullable) is None
        # and model_fields_set contains the field
        if self.delay_profile_ids is None and "delay_profile_ids" in self.model_fields_set:
            _dict['delayProfileIds'] = None

        # set to None if import_list_ids (nullable) is None
        # and model_fields_set contains the field
        if self.import_list_ids is None and "import_list_ids" in self.model_fields_set:
            _dict['importListIds'] = None

        # set to None if notification_ids (nullable) is None
        # and model_fields_set contains the field
        if self.notification_ids is None and "notification_ids" in self.model_fields_set:
            _dict['notificationIds'] = None

        # set to None if release_profile_ids (nullable) is None
        # and model_fields_set contains the field
        if self.release_profile_ids is None and "release_profile_ids" in self.model_fields_set:
            _dict['releaseProfileIds'] = None

        # set to None if indexer_ids (nullable) is None
        # and model_fields_set contains the field
        if self.indexer_ids is None and "indexer_ids" in self.model_fields_set:
            _dict['indexerIds'] = None

        # set to None if download_client_ids (nullable) is None
        # and model_fields_set contains the field
        if self.download_client_ids is None and "download_client_ids" in self.model_fields_set:
            _dict['downloadClientIds'] = None

        # set to None if auto_tag_ids (nullable) is None
        # and model_fields_set contains the field
        if self.auto_tag_ids is None and "auto_tag_ids" in self.model_fields_set:
            _dict['autoTagIds'] = None

        # set to None if movie_ids (nullable) is None
        # and model_fields_set contains the field
        if self.movie_ids is None and "movie_ids" in self.model_fields_set:
            _dict['movieIds'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TagDetailsResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "label": obj.get("label"),
            "delayProfileIds": obj.get("delayProfileIds"),
            "importListIds": obj.get("importListIds"),
            "notificationIds": obj.get("notificationIds"),
            "releaseProfileIds": obj.get("releaseProfileIds"),
            "indexerIds": obj.get("indexerIds"),
            "downloadClientIds": obj.get("downloadClientIds"),
            "autoTagIds": obj.get("autoTagIds"),
            "movieIds": obj.get("movieIds")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: v5.8.3.8933
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class CommandStatus(str, Enum):
    """
    CommandStatus
    """

    """
    allowed enum values
    """
    QUEUED = 'queued'
    STARTED = 'started'
    COMPLETED = 'completed'
    FAILED = 'failed'
    ABORTED = 'aborted'
    CANCELLED = 'cancelled'
    ORPHANED = 'orphaned'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CommandStatus from a JSON string"""
        return cls(json.loads(json_str))


